pub use read_lint_config::read_from_toml_or_else_vcs;
pub use set_status::set_status;

mod errors;
mod read_lint_config;
mod set_status;
#[cfg(test)]
mod set_status_test;
